{% extends 'django_auth2/base.html' %}

{% block content %}
    <h4 class="title text-info">Пароль был изменен</h4>

    <a class="btn btn-info button-form" href="{% url 'login' %}">Вход</a>
{% endblock %}