{% extends 'django_auth2/base.html' %}

{% block content %}

    <h4 class="text-info title">
        {{ request.user }}, ваш аккаунт успешно подтвержден.
    </h4>

    <br>
    <br>
    <a class="btn btn-info href" href="{% url 'index' %}">
        Продолжить
    </a>

{% endblock %}