{% extends 'django_auth2/base.html' %}

{% block content %}
    <h4 class="title text-info">Вход</h4>

    <form action="" method="post">
        {% csrf_token %}

        <div class="for-form">
            {% include 'django_auth2/fields_form.html' %}

            <button  type="submit" class="btn btn-default button-form">
                Войти
            </button>
        </div>

        <br>
        <br>
        <div style="width: 47%; float: left">
            <a class="align-right btn btn-default href" href="{% url 'register' %}"> Создать аккаунт </a>
        </div>
        <div style="width: 47%; margin-left: 6%; float: left">
            <a class="align-right btn btn-default href" href="{% url 'password_reset' %}"> Восстановить пароль </a>
        </div>

        <br>
        <a style="clear: left;" class="align-right btn btn-default href"
           href="{% url 'activate_re_send' %}">
            Выслать письмо с подтверждением еще раз
        </a>
    </form>
{% endblock %}