{% extends 'django_auth2/base.html' %}

{% block content %}
    <h4 class="title text-info">Сброс пароля</h4>

    <div class="text-support text-info">Введите ваш email</div>

    <form method="post">
        {% csrf_token %}
        <div class="for-form">
            {% include 'django_auth2/fields_form.html' %}
            <button type="submit" class="button-form btn btn-info">Отправить</button>
        </div>
    </form>

    <div class="text-info">
        На почту придет инструкция с последующими действиями.
    </div>

    <br>
    <br>

    <div style="width: 47%; float: left">
        <a class="align-right btn btn-default href" href="{% url 'login' %}"> Вход </a>
    </div>
{% endblock %}