{% extends 'django_auth2/base.html' %}

{% block content %}
    <h4 class="title text-info">Регистрация</h4>

    <div class="for-form ">
        <form action="" method="post">
            {% csrf_token %}
            {% include 'django_auth2/fields_form.html' %}
            <button class="btn btn-default button-form" type="submit">
                Зарегестрироваться
            </button>
        </form>
    </div>

    <div class="text-info">
        <p>
            После регистрации на почту придет сообщение для подтверждения акканута.
        </p>
        <p>
            Подтверждение действует 1 день.
        </p>
    </div>

    <h4 class="text-support">
        Вы уже зарегестрированы?
    </h4>
    <a class="btn blue href" href="{% url 'login' %}"> Вход </a>
{% endblock %}