{% extends 'django_auth2/base.html' %}

{% block content %}

    <h4 class="text-info title">
        На почту было отправлено сообщение с сылкой на восстановление пароля
    </h4>

    <div class="text-info">Для изменения пароля перейдите по ссылке в письме</div>
    <div class="text-info">
        Если вы не получили сообщение, значит почта была указана не правильно
    </div>

    <br>
    <br>
    <div style="width: 47%; float: left">
        <a class="align-right btn btn-default href" href="{% url 'login' %}"> Вход </a>
    </div>
    <div style="width: 47%; margin-left: 6%; float: left">
        <a class="align-right btn btn-default href" href="{% url 'password_reset' %}">
            Восстановить пароль
        </a>
    </div>
{% endblock %}