.block-content {
    margin-left:35%;
    width: 30%;
    margin-top: 5%;
    background-color: white;
    padding: 50px;;
    border-radius: 10px;
}
@media screen and (max-width: 720px) {
    .block-content {
        margin-left:10%;
        width: 80%;
        margin-top: 5%;
        background-color: white;
        padding: 5%;
        border-radius: 4px;
    }
}

body {
    background-color: #e1edff;
}

.button-form {
    background-color: #008CBA;
    padding: 10px 15px 10px 15px;
    font-size: 15px;
    border-radius: 4px;
    margin: 4px 2px;
    cursor: pointer;
    text-align: center;
    border: 1px solid ;
    text-decoration: none;
    color: white;
}

.title {
    color:  #008CBA;
    margin-bottom:  5%;
    font-size: 24px;
}

.href {
    background-color: #4A8CBA;
    padding: 5px;
    font-size: 15px;
    border-radius: 4px;
    margin: 5px;
    cursor: pointer;
    text-align: center;
    border: 1px solid #9f97b5;
    text-decoration: none;
    color: white;
    display: block;
}

.for-form {
    width: 80%;
    padding-left: 10%;
}

.input-label {
    color: #4e455d;
    font-size: 18px;
}

.input-text-block {
    border: 1px solid #cccccc;
    
    border-radius: 5px;
    -webkit-border-radius: 5px;
    -moz-border-radius: 3px;
    -khtml-border-radius: 3px;
    /*background: #ffffff !important; // желательно прописывать, так как в Chrome при сохранных данных оно может быть желтым*/
    outline: none; // удаляет обводку в браузерах хром(желтая) и сафари(синяя)
    color: #cccccc; //цвет шрифта в обычном состоянии
    font-family: Tahoma; // Стиль шрифта
    border: 20px;
    padding-left: 6px;
    display: block;
    width: 100%;
    height: 24px;
    font-size: 15px; // Размер шрифта
}
.input-text-block :focus{
    border: 2px solid #dcb7ff;
}

.text-info {
    color: #008CBA;
    /*text-indent: 1.5em; // красная строка*/
    /*text-align: justify; // выравнивание по ширине*/
}
.text-support {
    color: #006A98;
    font-size: 18px;
    /*text-indent: 1.5em; // красная строка*/
    /*text-align: justify; // выравнивание по ширине*/
}

.field_error {
    border: solid 2px #ba5055;
    border-radius: 5px;
    -webkit-border-radius: 5px;
    -moz-border-radius: 3px;
    -khtml-border-radius: 3px;
}
.text-danger {
    color: #ba5055;
}