{% extends 'django_auth2/base.html' %}

{% block content %}
    <h4 class="title text-info">Письмо с подтверждением отправлено</h4>

    <br>
    <p class="text-info">
        На вашу почту было отправлено письмо с подтсвержденим.
    </p>
    <p class="text-info">
        Перейдите по ссылке в письме, что бы подтвердить пользователя.
    </p>
{% endblock %}