<!DOCTYPE html>
<html>
{% load static %}
    <head>
        <title>Login</title>

        <link href="{% static 'django_auth2/css/base.css' %}" type="text/css" rel="stylesheet">

    </head>

    <body>
        <div class="block-content" >
            {% block content %}
            {% endblock content %}
        </div>
    </body>

</html>