{% autoescape off %}

    На вашу почту пришло сообщение с подвтерждением сообщения.

    Логин: {{ user.username }}

Для подтвердения аканута перейдите по ссылке ниже:
{{ protocol }}://{{ domain }}{% url 'password_reset_confirm' uidb64=uid token=token %}

Если не можете нажать на ссылку, скопируйте ее и вставьте в URL адресс в браузере.

    Be Happy ^~^
{% endautoescape %}