{% extends 'django_auth2/base.html' %}

{% block content %}

    <h4 class="text-info title">
        Выслать подтверждение аккаунта на почту
    </h4>

    <form action="" method="post" class="for-form">
        {% csrf_token %}
        {% include 'django_auth2/fields_form.html' %}
        <button class="btm btn-info button-form" type="submit">Выслать</button>
    </form>

    {% for field_errors in form.email.errors %}
        {% if field_errors == 'Аккаунт активен' %}
            <br>
            <a class="btn btn-info href" href="{% url 'password_reset' %}">Восстановить пароль</a>
        {% endif %}
    {% endfor %}

    {% if form.account_is_active %}
        <a class="btn btn-info href" href="{% url 'password_reset' %}">Восстановить пароль</a>
    {% endif %}



{% endblock %}