{% extends 'django_auth2/base.html' %}

{% block content %}
    {% if validlink %}
        <h4 class="title">Изменить пароль</h4>
        <form method="post">
            {% csrf_token %}

            <div class="for-form">
                {% include 'django_auth2/fields_form.html' %}
                <button class="btn btn-info button-form" type="submit">
                    Изменить пароль
                </button>
            </div>

        </form>
    {% else %}
        <p class="text-info">
            Ссылка для восстановления пароля не удачна
        </p>

        <div style="width: 47%; float: left">
            <a class="align-right btn btn-default href" href="{% url 'login' %}"> Вход </a>
        </div>
    {% endif %}

    <br>

{% endblock %}